==> qtjambi-qt3drender-6.5.7-sources.jar: io/qt/qt3d/render/QSubtreeEnabler.java <==
package io.qt.qt3d.render;

import io.qt.*;


/**
 * <p>Enables or disables entire subtrees of framegraph nodes</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qt3drender-qsubtreeenabler.html">Qt3DRender::QSubtreeEnabler</a></code></p>
 */
public class QSubtreeEnabler extends io.qt.qt3d.render.QFrameGraphNode
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QSubtreeEnabler.class);
    
    /**
     * <p>Java wrapper for Qt enum <code><a href="https://doc.qt.io/qt/qt3drender-qsubtreeenabler.html#Enablement-enum">Qt3DRender::QSubtreeEnabler::Enablement</a></code></p>
     */
    public enum Enablement implements QtEnumerator {
        /**
         * <p>Representing <code><a href="https://doc.qt.io/qt/qt3drender-qsubtreeenabler.html#Enablement-enum">Qt3DRender::<wbr/>QSubtreeEnabler::<wbr/>Persistent</a></code></p>
         */
        Persistent(0),
        /**
         * <p>Representing <code><a href="https://doc.qt.io/qt/qt3drender-qsubtreeenabler.html#Enablement-enum">Qt3DRender::<wbr/>QSubtreeEnabler::<wbr/>SingleShot</a></code></p>
         */
        SingleShot(1);

        static {
            QtJambi_LibraryUtilities.initialize();
        }

        private Enablement(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        @Override
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static @NonNull Enablement resolve(int value) {
            switch (value) {
            case 0: return Persistent;
            case 1: return SingleShot;
            default: throw new QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    

    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qsubtreeenabler.html#enablement-prop">Qt3DRender::QSubtreeEnabler::<wbr/>enablementChanged(Qt3DRender::QSubtreeEnabler::Enablement)</a></code></p>
     */
    @QtPropertyNotify(name="enablement")
    public final @NonNull Signal1<io.qt.qt3d.render.QSubtreeEnabler.@NonNull Enablement> enablementChanged = new Signal1<>();
    
    /**
     * <p>See <code>Qt3DRender::QSubtreeEnabler::<wbr/>QSubtreeEnabler(Qt3DCore::QNode*)</code></p>
     */
    @SuppressWarnings({"exports"})
    public QSubtreeEnabler(io.qt.qt3d.core.@Nullable QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QSubtreeEnabler instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qsubtreeenabler.html#enablement-prop">Qt3DRender::QSubtreeEnabler::<wbr/>enablement()const</a></code></p>
     */
    @QtPropertyReader(name="enablement")
    @QtUninvokable
    public final io.qt.qt3d.render.QSubtreeEnabler.@NonNull Enablement enablement(){
        return io.qt.qt3d.render.QSubtreeEnabler.Enablement.resolve(enablement_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @QtUninvokable
    private native int enablement_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qsubtreeenabler.html#requestUpdate">Qt3DRender::QSubtreeEnabler::<wbr/>requestUpdate()</a></code></p>
     */
    public final void requestUpdate(){
        requestUpdate_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native void requestUpdate_native(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qsubtreeenabler.html#enablement-prop">Qt3DRender::QSubtreeEnabler::<wbr/>setEnablement(Qt3DRender::QSubtreeEnabler::Enablement)</a></code></p>
     */
    @QtPropertyWriter(name="enablement")
    @QtUninvokable
    public final void setEnablement(io.qt.qt3d.render.QSubtreeEnabler.@NonNull Enablement enablement){
        setEnablement_native_Qt3DRender_QSubtreeEnabler_Enablement(QtJambi_LibraryUtilities.internal.nativeId(this), enablement.value());
    }
    
    @QtUninvokable
    private native void setEnablement_native_Qt3DRender_QSubtreeEnabler_Enablement(long __this__nativeId, int enablement);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QSubtreeEnabler(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     * @hidden
     */
    @NativeAccess
    protected QSubtreeEnabler(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QSubtreeEnabler instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QSubtreeEnabler(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QSubtreeEnabler() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #enablement()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final io.qt.qt3d.render.QSubtreeEnabler.@NonNull Enablement getEnablement() {
        return enablement();
    }
}

==> qtjambi-qt3drender-6.6.0-sources.jar: io/qt/qt3d/render/QSubtreeEnabler.java <==
package io.qt.qt3d.render;

import io.qt.*;


/**
 * <p>Enables or disables entire subtrees of framegraph nodes</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qt3drender-qsubtreeenabler.html">Qt3DRender::QSubtreeEnabler</a></code></p>
 */
public class QSubtreeEnabler extends io.qt.qt3d.render.QFrameGraphNode
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QSubtreeEnabler.class);
    
    /**
     * <p>Java wrapper for Qt enum <code><a href="https://doc.qt.io/qt/qt3drender-qsubtreeenabler.html#Enablement-enum">Qt3DRender::QSubtreeEnabler::Enablement</a></code></p>
     */
    public enum Enablement implements QtEnumerator {
        /**
         * <p>Representing <code><a href="https://doc.qt.io/qt/qt3drender-qsubtreeenabler.html#Enablement-enum">Qt3DRender::<wbr>QSubtreeEnabler::<wbr>Persistent</a></code></p>
         */
        Persistent(0),
        /**
         * <p>Representing <code><a href="https://doc.qt.io/qt/qt3drender-qsubtreeenabler.html#Enablement-enum">Qt3DRender::<wbr>QSubtreeEnabler::<wbr>SingleShot</a></code></p>
         */
        SingleShot(1);

        static {
            QtJambi_LibraryUtilities.initialize();
        }

        private Enablement(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static @NonNull Enablement resolve(int value) {
            switch (value) {
            case 0: return Persistent;
            case 1: return SingleShot;
            default: throw new QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    

    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qsubtreeenabler.html#enablement-prop">Qt3DRender::QSubtreeEnabler::<wbr>enablementChanged(Qt3DRender::QSubtreeEnabler::Enablement)</a></code></p>
     */
    @QtPropertyNotify(name="enablement")
    public final @NonNull Signal1<io.qt.qt3d.render.QSubtreeEnabler.@NonNull Enablement> enablementChanged = new Signal1<>();
    
    /**
     * <p>See <code>Qt3DRender::QSubtreeEnabler::<wbr>QSubtreeEnabler(Qt3DCore::QNode*)</code></p>
     */
    @SuppressWarnings({"exports"})
    public QSubtreeEnabler(io.qt.qt3d.core.@Nullable QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QSubtreeEnabler instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qsubtreeenabler.html#enablement-prop">Qt3DRender::QSubtreeEnabler::<wbr>enablement()const</a></code></p>
     */
    @QtPropertyReader(name="enablement")
    @QtUninvokable
    public final io.qt.qt3d.render.QSubtreeEnabler.@NonNull Enablement enablement(){
        return io.qt.qt3d.render.QSubtreeEnabler.Enablement.resolve(enablement_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @QtUninvokable
    private native int enablement_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qsubtreeenabler.html#requestUpdate">Qt3DRender::QSubtreeEnabler::<wbr>requestUpdate()</a></code></p>
     */
    public final void requestUpdate(){
        requestUpdate_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native void requestUpdate_native(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qsubtreeenabler.html#enablement-prop">Qt3DRender::QSubtreeEnabler::<wbr>setEnablement(Qt3DRender::QSubtreeEnabler::Enablement)</a></code></p>
     */
    @QtPropertyWriter(name="enablement")
    @QtUninvokable
    public final void setEnablement(io.qt.qt3d.render.QSubtreeEnabler.@NonNull Enablement enablement){
        setEnablement_native_Qt3DRender_QSubtreeEnabler_Enablement(QtJambi_LibraryUtilities.internal.nativeId(this), enablement.value());
    }
    
    @QtUninvokable
    private native void setEnablement_native_Qt3DRender_QSubtreeEnabler_Enablement(long __this__nativeId, int enablement);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QSubtreeEnabler(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * @hidden
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QSubtreeEnabler(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QSubtreeEnabler instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QSubtreeEnabler(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QSubtreeEnabler() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>Kotlin property getter. In Java use {@link #enablement()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final io.qt.qt3d.render.QSubtreeEnabler.@NonNull Enablement getEnablement() {
        return enablement();
    }
}
